summaryrefslogtreecommitdiff
path: root/graphics/xfig/patches/patch-ab
blob: 6fb89a1e5b01d10e86f77b3dd8a18010d0fb1b16 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
$NetBSD: patch-ab,v 1.1 1999/01/05 21:37:55 frueauf Exp $

--- w_help.c-orig	Tue Jun 16 18:06:43 1998
+++ w_help.c	Tue Jan  5 21:41:46 1999
@@ -33,13 +33,13 @@
 	char filename[PATH_MAX];
 
 	/* first check if at least the index file is installed */
-	sprintf(filename, "%s/html/index.html", XFIGLIBDIR);
+	sprintf(filename, "%s/html/index.html", XFIGDOCDIR);
 #ifdef I18N
 	if (appres.international && getenv("LANG")) {
-	  /* check localized file ($XFIGLIBDIR/html/$LANG/index.html) first */
-	  sprintf(filename, "%s/html/%s/index.html", XFIGLIBDIR, getenv("LANG"));
+	  /* check localized file ($XFIGDOCDIR/html/$LANG/index.html) first */
+	  sprintf(filename, "%s/html/%s/index.html", XFIGDOCDIR, getenv("LANG"));
 	  if (!check_docfile(filename))
-	    sprintf(filename, "%s/html/index.html", XFIGLIBDIR);
+	    sprintf(filename, "%s/html/index.html", XFIGDOCDIR);
 	}
 #endif
 	if (!check_docfile(filename))
@@ -63,13 +63,13 @@
 	int pid;
 
 	/* first check if the file is installed */
-	sprintf(cmd,"%s/xfig-howto.pdf",XFIGLIBDIR);
+	sprintf(cmd,"%s/xfig-howto.pdf",XFIGDOCDIR);
 	if (!check_docfile(cmd))
 		return;
 	pid = fork();
 	if (pid == 0) {
 	    /* child process launches pdf viewer */
-	    sprintf(cmd,"%s %s/xfig-howto.pdf &",appres.pdf_viewer,XFIGLIBDIR);
+	    sprintf(cmd,"%s %s/xfig-howto.pdf &",appres.pdf_viewer,XFIGDOCDIR);
 	    system(cmd);
 	    exit(0);
 	}
@@ -84,14 +84,14 @@
 	int pid;
 
 	/* first check if the file is installed */
-	sprintf(cmd,"%s/xfig.pdf",XFIGLIBDIR);
+	sprintf(cmd,"%s/xfig.pdf",XFIGDOCDIR);
 	if (!check_docfile(cmd))
 		return;
 	put_msg("Launching %s for man pages",appres.pdf_viewer);
 	pid = fork();
 	if (pid == 0) {
 	    /* child process launches pdf viewer */
-	    sprintf(cmd,"%s %s/xfig.pdf &",appres.pdf_viewer,XFIGLIBDIR);
+	    sprintf(cmd,"%s %s/xfig.pdf &",appres.pdf_viewer,XFIGDOCDIR);
 	    system(cmd);
 	    exit(0);
 	}